==> epiphany-0.5.0.tar.gz: epiphany-0.5.0/lib/ephy-stock-icons.h <==
/*
 *  Copyright (C) 2002 Jorn Baayen
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 *  $Id: ephy-stock-icons.h,v 1.6 2003/03/24 20:08:05 Bordoley Exp $
 */

#ifndef EPHY_STOCK_ICONS_H
#define EPHY_STOCK_ICONS_H

G_BEGIN_DECLS

#define EPHY_STOCK_SECURE          "epiphany-secure"
#define EPHY_STOCK_UNSECURE        "epiphany-unsecure"
#define EPHY_STOCK_HISTORY         "epiphany-history"
#define EPHY_STOCK_BOOKMARKS       "epiphany-bookmarks"
#define EPHY_STOCK_BOOKMARK_PAGE "epiphany-bookmark-page"
#define EPHY_STOCK_NEW_TAB         "epiphany-new-tab"
#define EPHY_STOCK_FULLSCREEN      "epiphany-fullscreen"
#define EPHY_STOCK_VIEWSOURCE      "epiphany-viewsource"
#define EPHY_STOCK_SEND_LINK       "epiphany-send-link"
#define EPHY_STOCK_ENTRY		    "epiphany-entry"

void ephy_stock_icons_init (void);

G_END_DECLS

#endif /* EPHY_STOCK_ICONS_H */

==> epiphany-1.1.1.tar.gz: epiphany-1.1.1/lib/ephy-stock-icons.h <==
/*
 *  Copyright (C) 2002 Jorn Baayen
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 *  $Id: ephy-stock-icons.h,v 1.9 2003/11/22 14:40:37 marco Exp $
 */

#ifndef EPHY_STOCK_ICONS_H
#define EPHY_STOCK_ICONS_H

G_BEGIN_DECLS

#define EPHY_STOCK_SECURE          "epiphany-secure"
#define EPHY_STOCK_UNSECURE        "epiphany-unsecure"
#define EPHY_STOCK_HISTORY         "epiphany-history"
#define EPHY_STOCK_BOOKMARKS       "epiphany-bookmarks"
#define EPHY_STOCK_ENTRY	   "epiphany-entry"
#define EPHY_STOCK_DOWNLOAD	   "epiphany-download"

#define STOCK_NEW_TAB		   "stock_new-tab"
#define STOCK_FULLSCREEN	   "stock_fullscreen"
#define STOCK_VIEW_SOURCE	   "stock_view-html-source"
#define STOCK_SEND_MAIL		   "stock_mail_send"
#define STOCK_ADD_BOOKMARK	   "stock_add-bookmark"

void ephy_stock_icons_init (void);

G_END_DECLS

#endif /* EPHY_STOCK_ICONS_H */
